/*
    Copyright (c) 2020 TDE Team

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef _PLUGIN_EXPORTS_H_
#define _PLUGIN_EXPORTS_H_

#ifdef __KDE_HAVE_GCC_VISIBILITY
#define PLUGIN_NO_EXPORT __attribute__ ((visibility("hidden")))
#define PLUGIN_EXPORT __attribute__ ((visibility("default")))
#elif defined(TQ_WS_WIN)
#define PLUGIN_NO_EXPORT
#define PLUGIN_EXPORT __declspec(dllexport)
#else
#define PLUGIN_NO_EXPORT
#define PLUGIN_EXPORT
#endif

#endif /* _PLUGIN_EXPORTS_H_ */
